==> piwigo_2.2.2.orig.tar.gz: piwigo/language/sv_SE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grund Inställningar';
$lang['Default gallery language'] = 'Standard språk för galleriet';
$lang['Database configuration'] = 'Databas konfiguration';
$lang['Admin configuration'] = 'Admin konfiguration';
$lang['Start Install'] = 'Påbörja installation';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'E-mail adressen måste se ut som följande: xxx@yyy.eee (exempel : jack@altern.org)';
$lang['Webmaster login'] = 'Webbansvarig login';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det kommer att visas för besökare. Det är nödvändigt för administrering av hemsidan.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Ansluten till server, men kunde inte ansluta till databasen.';
$lang['Can\'t connect to server'] = 'Kan inte ansluta till servern';
$lang['Database type'] = 'Databas typ';
$lang['The type of database your piwigo data will be store in'] = 'Ange vilken typ av databas din Piwigo data ska lagras i.';
$lang['Host'] = 'Värd';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Användare';
$lang['user login given by your host provider'] = 'användares inloggning given av ditt webbhotell';
$lang['Password'] = 'Lösenord';
$lang['user password given by your host provider'] = 'användares lösenord given av ditt webbhotell';
$lang['Database name'] = 'Databas namn';
$lang['also given by your host provider'] = 'också tilldelad av din webbhotell';
$lang['Database table prefix'] = 'Prefix för tabeller i Databasen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'tabellernas namn i databasen kommer att bli prefixerad med det (detta gör att du kan hantera dina tabeller bättre)';
$lang['enter a login for webmaster'] = 'ange inloggning för webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'login för webmaster får inte innehålla symbolerna \' eller "';
$lang['please enter your password again'] = 'ange ditt lösenord igen';
$lang['Webmaster password'] = 'Webmaster lösenord';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Håll det hemligt, lösenordet ger dig tillgång till administrationspanelen';
$lang['Password [confirm]'] = 'Lösenord [bekräfta]';
$lang['verification'] = 'verifiering';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Behöver du hjälp? Ställ din fråga på <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmaster e-mail adress';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besökare kommer att kunna kontakta sidans administratör med denna e-mail adress';
$lang['PHP 5 is required'] = 'PHP 5 krävs';
$lang['It appears your webhost is currently running PHP %s.'] = 'Ditt webbhotell använder just nu PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan kanske komma att ändra dina inställningar i PHP 5 genom att skapa eller ändra en .htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Notera att du kan ändra dina inställningar förutsatt att du startar om Piwigo efteråt.';
$lang['Try to configure PHP 5'] = 'Försök att konfigurera PHP 5';
$lang['Sorry!'] = 'Ursäkta!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kunde inte konfigurera PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Vi rekomenderar att du kontaktar leverantören för ditt webbhotell för att se hur du kan ändra till PHP 5.';
$lang['Hope to see you back soon.'] = 'Välkommen tillbaka snart igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulerar, Piwigo installationen är klar';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ lösning är att kopiera texten ovan och klistra in i filen "local/config/database.inc.php" (Varning : database.inc.php får enbart innehålla texten från textarean, inga radbrytare eller mellanrum)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Kunde inte skapa filen local/config/database.inc.php .';
$lang['Download the config file'] = 'Ladda ner konfigurations filen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan ladda ner konfigurationsfilen och ladda upp den till local/config .';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite och PostgreSQL är för tillfället i försöksstadie.';
$lang['Learn more'] = 'Läs mer';
?>

==> piwigo_2.3.1.orig.tar.gz: piwigo/language/sv_SE/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grund Inställningar';
$lang['Default gallery language'] = 'Standard språk för galleriet';
$lang['Database configuration'] = 'Databas konfiguration';
$lang['Admin configuration'] = 'Admin konfiguration';
$lang['Start Install'] = 'Påbörja installation';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'E-mail adressen måste se ut som följande: xxx@yyy.eee (exempel : jack@altern.org)';
$lang['Webmaster login'] = 'Webbansvarig login';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det kommer att visas för besökare. Det är nödvändigt för administrering av hemsidan.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Ansluten till server, men kunde inte ansluta till databasen.';
$lang['Can\'t connect to server'] = 'Kan inte ansluta till servern';
$lang['Host'] = 'Värd';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Användare';
$lang['user login given by your host provider'] = 'användares inloggning given av ditt webbhotell';
$lang['Password'] = 'Lösenord';
$lang['user password given by your host provider'] = 'användares lösenord given av ditt webbhotell';
$lang['Database name'] = 'Databas namn';
$lang['also given by your host provider'] = 'också tilldelad av din webbhotell';
$lang['Database table prefix'] = 'Prefix för tabeller i Databasen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'tabellernas namn i databasen kommer att bli prefixerad med det (detta gör att du kan hantera dina tabeller bättre)';
$lang['enter a login for webmaster'] = 'ange inloggning för webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'login för webmaster får inte innehålla symbolerna \' eller "';
$lang['please enter your password again'] = 'ange ditt lösenord igen';
$lang['Webmaster password'] = 'Webmaster lösenord';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Håll det hemligt, lösenordet ger dig tillgång till administrationspanelen';
$lang['Password [confirm]'] = 'Lösenord [bekräfta]';
$lang['verification'] = 'verifiering';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Behöver du hjälp? Ställ din fråga på <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmaster e-mail adress';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besökare kommer att kunna kontakta sidans administratör med denna e-mail adress';
$lang['PHP 5 is required'] = 'PHP 5 krävs';
$lang['It appears your webhost is currently running PHP %s.'] = 'Ditt webbhotell använder just nu PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan kanske komma att ändra dina inställningar i PHP 5 genom att skapa eller ändra en .htaccess fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Notera att du kan ändra dina inställningar förutsatt att du startar om Piwigo efteråt.';
$lang['Try to configure PHP 5'] = 'Försök att konfigurera PHP 5';
$lang['Sorry!'] = 'Ursäkta!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kunde inte konfigurera PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Vi rekomenderar att du kontaktar leverantören för ditt webbhotell för att se hur du kan ändra till PHP 5.';
$lang['Hope to see you back soon.'] = 'Välkommen tillbaka snart igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Gratulerar, Piwigo installationen är klar';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ lösning är att kopiera texten ovan och klistra in i filen "local/config/database.inc.php" (Varning : database.inc.php får enbart innehålla texten från textarean, inga radbrytare eller mellanrum)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Kunde inte skapa filen local/config/database.inc.php .';
$lang['Download the config file'] = 'Ladda ner konfigurations filen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan ladda ner konfigurationsfilen och ladda upp den till local/config .';
$lang['Just another Piwigo gallery'] = 'Ännu ett Piwigo galleri';
$lang['Welcome to my photo gallery'] = 'Välkommen till mitt fotogalleri';


?>
